@@ -74,11 +74,18 @@ class SavedDataTraversal(WrapperWidgetTraversal):
 
 class SavedDataView(BrowserView):
     def items(self):
-        return [
+        items = [
             (name, action.__doc__)
             for name, action in getFieldsInOrder(get_actions(self.context))
             if ISaveData.providedBy(action)
         ]
+        if len(items) == 1:
+            url = "{0}/actions/{1}/@@data".format(
+                self.context.absolute_url(),
+                items[0][0],
+            )
+            self.request.response.redirect(url)
+        return items
 
 
 class DataWrapper(dict):
@@ -92,6 +99,10 @@ class SavedDataForm(crud.CrudForm):
     template = ViewPageTemplateFile("saveddata_form.pt")
     addform_factory = crud.NullForm
 
+    @property
+    def form_title(self):
+        return aq_parent(self).Title()
+
     @property
     def field(self):
         return self.context.field
