@@ -7,7 +7,7 @@ from plone import api
 from plone.app.textfield import RichText
 from plone.autoform import directives
 from plone.schema import Email
-from plone.supermodel.model import fieldset
+from plone.supermodel.directives import fieldset
 from Products.CMFPlone.utils import safe_unicode
 from z3c.form.browser.checkbox import CheckBoxFieldWidget
 from z3c.form.browser.textarea import TextAreaWidget
@@ -22,9 +22,8 @@ MODIFY_PORTAL_CONTENT = "cmf.ModifyPortalContent"
 
 
 def default_mail_body():
-    """ Default mail body for mailer action
-
-        Acquire 'mail_body_default.pt' or return hard coded default
+    """ Default mail body for mailer action.
+    Acquire 'mail_body_default.pt' or return hard coded default
     """
     try:
         portal = api.portal.get()
@@ -75,7 +74,7 @@ class IMailer(IAction):
         label=_("Addressing"),
         fields=["to_field", "cc_recipients", "bcc_recipients", "replyto_field"],
     )
-    directives.write_permission(to_field=config.EDIT_ADVANCED_PERMISSION)
+    directives.write_permission(to_field=config.EDIT_ADDRESSING_PERMISSION)
     directives.read_permission(to_field=MODIFY_PORTAL_CONTENT)
     to_field = zope.schema.Choice(
         title=_(u"label_formmailer_to_extract", default=u"Extract Recipient From"),
@@ -117,7 +116,7 @@ class IMailer(IAction):
         required=False,
     )
 
-    directives.write_permission(replyto_field=config.EDIT_ADVANCED_PERMISSION)
+    directives.write_permission(replyto_field=config.EDIT_TECHNICAL_PERMISSION)
     directives.read_permission(replyto_field=MODIFY_PORTAL_CONTENT)
     replyto_field = zope.schema.Choice(
         title=_(u"label_formmailer_replyto_extract", default=u"Extract Reply-To From"),
@@ -326,7 +325,7 @@ class IMailer(IAction):
         u"headers", label=_("Headers"), fields=["xinfo_headers", "additional_headers"]
     )
     directives.widget(xinfo_headers=CheckBoxFieldWidget)
-    directives.write_permission(xinfo_headers=config.EDIT_ADVANCED_PERMISSION)
+    directives.write_permission(xinfo_headers=config.EDIT_TECHNICAL_PERMISSION)
     directives.read_permission(xinfo_headers=MODIFY_PORTAL_CONTENT)
     xinfo_headers = zope.schema.List(
         title=_(u"label_xinfo_headers_text", default=u"HTTP Headers"),
@@ -342,7 +341,7 @@ class IMailer(IAction):
         missing_value=[u"HTTP_X_FORWARDED_FOR", u"REMOTE_ADDR", u"PATH_INFO"],
         value_type=zope.schema.Choice(vocabulary="easyform.XinfoHeaders"),
     )
-    directives.write_permission(additional_headers=config.EDIT_ADVANCED_PERMISSION)
+    directives.write_permission(additional_headers=config.EDIT_TECHNICAL_PERMISSION)
     directives.read_permission(additional_headers=MODIFY_PORTAL_CONTENT)
     additional_headers = zope.schema.List(
         title=_(u"label_formmailer_additional_headers", default=u"Additional Headers"),
